@@ -1,49 +1,49 @@
 #' @title Summary of principal component analysis as HTML table
 #' @name sjt.pca
-#' 
-#' @description Performes a principle component analysis on a data frame or matrix 
-#'                (with varimax rotation) and displays the factor solution as HTML 
-#'                table, or saves them as file. \cr \cr In case a data frame is used as 
+#'
+#' @description Performes a principle component analysis on a data frame or matrix
+#'                (with varimax or oblimin rotation) and displays the factor solution as HTML
+#'                table, or saves them as file. \cr \cr In case a data frame is used as
 #'                parameter, the Cronbach's Alpha value for each factor scale will be calculated,
 #'                i.e. all variables with the highest loading for a factor are taken for the
 #'                reliability test. The result is an alpha value for each factor dimension.
-#' 
+#'
 #' @seealso \itemize{
 #'            \item \href{http://www.strengejacke.de/sjPlot/sjt.pca/}{sjPlot manual: sjt.pca}
 #'            \item \code{\link{sjp.pca}}
 #'          }
-#' 
-#' @param data \code{data.frame} that should be used to compute a PCA, or a \code{\link{prcomp}} object.
-#' @param rotation rotation of the factor loadings. May be \code{"varimax"} for orthogonal rotation
+#'
+#' @param data A data frame that should be used to compute a PCA, or a \code{\link{prcomp}} object.
+#' @param rotation Rotation of the factor loadings. May be \code{"varimax"} for orthogonal rotation
 #'          or \code{"oblimin"} for oblique transformation.
-#' @param nmbr.fctr number of factors used for calculating the varimax
+#' @param nmbr.fctr Number of factors used for calculating the varimax
 #'          rotation. By default, this value is \code{NULL} and the amount of factors is
 #'          calculated according to the Kaiser-criteria.
-#' @param fctr.load.tlrn specifies the minimum difference a variable needs to have between
+#' @param fctr.load.tlrn Specifies the minimum difference a variable needs to have between
 #'          factor loadings (components) in order to indicate a clear loading on just one factor and not
-#'          diffusing over all factors. For instance, a variable with 0.8, 0.82 and 0.84 factor loading 
+#'          diffusing over all factors. For instance, a variable with 0.8, 0.82 and 0.84 factor loading
 #'          on 3 possible factors can not be clearly assigned to just one factor and thus would be removed
 #'          from the principal component analysis. By default, the minimum difference of loading values
 #'          between the highest and 2nd highest factor should be 0.1
-#' @param show.cronb logical, if \code{TRUE} (default), the cronbach's alpha value for each factor scale will be calculated,
+#' @param show.cronb Logical, if \code{TRUE} (default), the cronbach's alpha value for each factor scale will be calculated,
 #'          i.e. all variables with the highest loading for a factor are taken for the
 #'          reliability test. The result is an alpha value for each factor dimension.
 #'          Only applies when \code{data} is a data frame and no \code{\link{prcomp}} object.
-#' @param show.msa logical, if \code{TRUE}, shows an additional column with the measure of sampling adequacy according
+#' @param show.msa Logical, if \code{TRUE}, shows an additional column with the measure of sampling adequacy according
 #'          dor each component.
-#' @param show.var logical, if \code{TRUE}, the proportions of variances for each component as well as cumulative
+#' @param show.var Logical, if \code{TRUE}, the proportions of variances for each component as well as cumulative
 #'          variance are shown in the table footer.
-#' @param string.pov string for the table row that contains the proportions of variances. By default, 
+#' @param string.pov String for the table row that contains the proportions of variances. By default,
 #'          \emph{"Proportion of Variance"} will be used.
-#' @param string.cpov string for the table row that contains the cumulative variances. By default, 
+#' @param string.cpov String for the table row that contains the cumulative variances. By default,
 #'          \emph{"Cumulative Proportion"} will be used.
-#'          
+#'
 #' @inheritParams sjt.frq
 #' @inheritParams sjt.xtab
 #' @inheritParams sjt.df
 #' @inheritParams sjp.grpfrq
 #' @inheritParams sjt.corr
-#'          
+#'
 #' @return Invisibly returns
 #'          \itemize{
 #'            \item the web page style sheet (\code{page.style}),
@@ -56,35 +56,23 @@
 #'            for further use.
 #'
 #' @note See 'Notes' in \code{\link{sjt.frq}}.
-#'        This PCA uses the \code{\link{prcomp}} function and 
-#'        the \code{\link{varimax}} rotation.
-#'  
+#'
 #' @details See 'Details' in \code{\link{sjt.frq}}.
-#'         
-#' 
+#'
+#'
 #' @examples
 #' \dontrun{
 #' # Data from the EUROFAMCARE sample dataset
 #' library(sjmisc)
 #' data(efc)
-#' 
-#' # retrieve variable and value labels
-#' varlabs <- get_label(efc)
-#' 
+#'
 #' # recveive first item of COPE-index scale
 #' start <- which(colnames(efc) == "c82cop1")
 #' # recveive last item of COPE-index scale
 #' end <- which(colnames(efc) == "c90cop9")
-#'  
-#' # create data frame with COPE-index scale
-#' mydf <- as.data.frame(efc[, c(start:end)])
-#' colnames(mydf) <- varlabs[c(start:end)]
-#' 
-#' sjt.pca(mydf)
-#' 
 #' # auto-detection of labels
 #' sjt.pca(efc[, c(start:end)])}
-#' 
+#'
 #' @importFrom psych KMO
 #' @importFrom stats prcomp
 #' @export
@@ -129,9 +117,9 @@ sjt.pca <- function(data,
     show.msa <- FALSE
   } else {
     pcadata <- stats::prcomp(
-      stats::na.omit(data), 
-      retx = TRUE, 
-      center = TRUE, 
+      stats::na.omit(data),
+      retx = TRUE,
+      center = TRUE,
       scale. = TRUE
     )
     dataframeparam <- TRUE
@@ -139,7 +127,7 @@ sjt.pca <- function(data,
   # -------------------------------------
   # init header
   # -------------------------------------
-  toWrite <- sprintf("<html>\n<head>\n<meta http-equiv=\"Content-type\" content=\"text/html;charset=%s\">\n", encoding)
+  toWrite <- table.header <- sprintf("<html>\n<head>\n<meta http-equiv=\"Content-type\" content=\"text/html;charset=%s\">\n", encoding)
   # -------------------------------------
   # init style sheet and tags used for css-definitions
   # we can use these variables for string-replacement
@@ -151,12 +139,12 @@ sjt.pca <- function(data,
   tag.tdata <- "tdata"
   tag.centeralign <- "centeralign"
   tag.rightalign <- "rightalign"
-  tag.cronbach <- "cronbach"  
-  tag.msa <- "msa"  
-  tag.pov <- "pov"  
+  tag.cronbach <- "cronbach"
+  tag.msa <- "msa"
+  tag.pov <- "pov"
   tag.cpov <- "cpov"
   tag.rotation <- "rotation"
-  tag.kmo <- "kmo"  
+  tag.kmo <- "kmo"
   tag.arc <- "arc"
   tag.minval <- "minval"
   tag.removable <- "removable"
@@ -168,12 +156,12 @@ sjt.pca <- function(data,
   css.tdata <- "padding:0.2cm;"
   css.centeralign <- "text-align:center;"
   css.rightalign <- "text-align:right;"
-  css.cronbach <- "font-style:italic;"  
-  css.msa <- "font-style:italic; color:#666666;"  
-  css.kmo <- "font-style:italic; border-bottom:double;"  
-  css.rotation <- "font-style:italic; font-size:0.9em;"  
-  css.pov <- "font-style:italic; border-top:1px solid;"  
-  css.cpov <- "font-style:italic;"  
+  css.cronbach <- "font-style:italic;"
+  css.msa <- "font-style:italic; color:#666666;"
+  css.kmo <- "font-style:italic; border-bottom:double;"
+  css.rotation <- "font-style:italic; font-size:0.9em;"
+  css.pov <- "font-style:italic; border-top:1px solid;"
+  css.cpov <- "font-style:italic;"
   css.minval <- "color:#cccccc;"
   css.arc <- "background-color:#eaeaea;"
   css.removable <- "background-color:#eacccc;"
@@ -210,12 +198,12 @@ sjt.pca <- function(data,
   # set page style
   # ------------------------
   page.style <-  sprintf("<style>%s { %s }\n%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n</style>",
-                         tag.table, css.table, tag.caption, css.caption, tag.thead, css.thead, 
+                         tag.table, css.table, tag.caption, css.caption, tag.thead, css.thead,
                          tag.tdata, css.tdata, tag.cronbach, css.cronbach, tag.minval, css.minval,
                          tag.removable, css.removable, tag.firsttablerow, css.firsttablerow,
                          tag.firsttablecol, css.firsttablecol, tag.centeralign, css.centeralign,
                          tag.rightalign, css.rightalign, tag.rotation, css.rotation,
-                         tag.msa, css.msa, tag.kmo, css.kmo, tag.pov, css.pov, tag.cpov, 
+                         tag.msa, css.msa, tag.kmo, css.kmo, tag.pov, css.pov, tag.cpov,
                          css.cpov, tag.arc, css.arc)
   # ------------------------
   # start content
@@ -236,13 +224,13 @@ sjt.pca <- function(data,
   # --------------------------------------------------------
   # check for predefined number of factors
   if (!is.null(nmbr.fctr) && is.numeric(nmbr.fctr)) pcadata.kaiser <- nmbr.fctr
-  
+
   # rotate matrix
   if (rotation == "varimax")
     pcadata.rotate <- varimaxrota(pcadata, pcadata.kaiser)
   else if (rotation == "oblimin")
     pcadata.rotate <- psych::principal(r = data, nfactors = pcadata.kaiser, rotate = "oblimin")
-  
+
   # create data frame with factor loadings
   df <- as.data.frame(pcadata.rotate$loadings[, seq_len(ncol(pcadata.rotate$loadings))])
   # ----------------------------
@@ -289,7 +277,7 @@ sjt.pca <- function(data,
   # --------------------------------------------------------
   # this function retrieves a list with the column index ("factor" index)
   # where each case of the data frame has its highedt factor loading.
-  # So we know to which "group" (factor dimension) each case of the 
+  # So we know to which "group" (factor dimension) each case of the
   # data frame belongs to according to the pca results
   # --------------------------------------------------------
   getItemLoadings <- function(dataframe) {
@@ -395,22 +383,22 @@ sjt.pca <- function(data,
     # write tr-tag with class-attributes
     page.content <- paste0(page.content, "  <tr>\n")
     # print first table cell
-    page.content <- paste0(page.content, sprintf("    <td class=\"firsttablecol%s%s\">%s</td>\n", 
+    page.content <- paste0(page.content, sprintf("    <td class=\"firsttablecol%s%s\">%s</td>\n",
                                                  arcstring, rowcss, var.labels[i]))
     # iterate all columns
     for (j in seq_len(ncol(df))) {
       # start table column
       colcss <- sprintf(" class=\"tdata centeralign%s%s\"", arcstring, rowcss)
-      if (maxdf[[i]] != max(abs(df[i, j]))) 
+      if (maxdf[[i]] != max(abs(df[i, j])))
         colcss <- sprintf(" class=\"tdata centeralign minval%s%s\"", arcstring, rowcss)
-      page.content <- paste0(page.content, sprintf("    <td%s>%.*f</td>\n", 
+      page.content <- paste0(page.content, sprintf("    <td%s>%.*f</td>\n",
                                                    colcss, digits, df[i, j]))
     }
     # check if msa column should be shown
-    if (show.msa) page.content <- paste0(page.content, sprintf("    <td class=\"tdata msa centeralign%s%s\">%.*f</td>\n", 
-                                                              arcstring, 
-                                                              rowcss, 
-                                                              digits, 
+    if (show.msa) page.content <- paste0(page.content, sprintf("    <td class=\"tdata msa centeralign%s%s\">%.*f</td>\n",
+                                                              arcstring,
+                                                              rowcss,
+                                                              digits,
                                                               kmo$MSAi[[i]]))
     # close row
     page.content <- paste0(page.content, "  </tr>\n")
@@ -425,8 +413,8 @@ sjt.pca <- function(data,
     page.content <- paste0(page.content, sprintf("    <td class=\"tdata pov\">%s</td>\n", string.pov))
     # iterate alpha-values
     for (i in 1:length(pov)) {
-      page.content <- paste0(page.content, sprintf("    <td class=\"tdata centeralign pov\">%.*f&nbsp;%%</td>\n", 
-                                                   digits, 
+      page.content <- paste0(page.content, sprintf("    <td class=\"tdata centeralign pov\">%.*f&nbsp;%%</td>\n",
+                                                   digits,
                                                    100 * pov[i]))
     }
     # check if msa column should be shown
@@ -436,8 +424,8 @@ sjt.pca <- function(data,
     page.content <- paste0(page.content, sprintf("    <td class=\"tdata cpov\">%s</td>\n", string.cpov))
     # iterate alpha-values
     for (i in 1:length(pov)) {
-      page.content <- paste0(page.content, sprintf("    <td class=\"tdata centeralign cpov\">%.*f&nbsp;%%</td>\n", 
-                                                   digits, 
+      page.content <- paste0(page.content, sprintf("    <td class=\"tdata centeralign cpov\">%.*f&nbsp;%%</td>\n",
+                                                   digits,
                                                    100 * cpov[i]))
     }
     # check if msa column should be shown
@@ -454,8 +442,8 @@ sjt.pca <- function(data,
     page.content <- paste0(page.content, "    <td class=\"tdata cronbach\">Cronbach's &alpha;</td>\n")
     # iterate alpha-values
     for (i in seq_len(length(alphaValues))) {
-      page.content <- paste0(page.content, sprintf("    <td class=\"tdata centeralign cronbach\">%.*f</td>\n", 
-                                                   digits, 
+      page.content <- paste0(page.content, sprintf("    <td class=\"tdata centeralign cronbach\">%.*f</td>\n",
+                                                   digits,
                                                    alphaValues[i]))
     }
     # check if msa column should be shown
@@ -523,10 +511,10 @@ sjt.pca <- function(data,
   knitr <- gsub(tag.cpov, css.cpov, knitr, fixed = TRUE, useBytes = TRUE)
   knitr <- gsub(tag.kmo, css.kmo, knitr, fixed = TRUE, useBytes = TRUE)
   knitr <- gsub(tag.rotation, css.rotation, knitr, fixed = TRUE, useBytes = TRUE)
-  knitr <- gsub(tag.minval, css.minval, knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.removable, css.removable, knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.firsttablerow, css.firsttablerow, knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.firsttablecol, css.firsttablecol, knitr, fixed = TRUE, useBytes = TRUE)  
+  knitr <- gsub(tag.minval, css.minval, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.removable, css.removable, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.firsttablerow, css.firsttablerow, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.firsttablecol, css.firsttablecol, knitr, fixed = TRUE, useBytes = TRUE)
   # -------------------------------------
   # remove spaces?
   # -------------------------------------
@@ -536,17 +524,17 @@ sjt.pca <- function(data,
     page.content <- sju.rmspc(page.content)
   }
   # -------------------------------------
-  # check if html-content should be outputted
-  # -------------------------------------
-  out.html.table(no.output, file, knitr, toWrite, use.viewer) 
-  # -------------------------------------
   # return results
   # -------------------------------------
-  invisible(structure(class = c("sjTable", "sjtpca"),
+  structure(class = c("sjTable", "sjtpca"),
                       list(page.style = page.style,
                            page.content = page.content,
                            output.complete = toWrite,
                            knitr = knitr,
                            factor.index = factorindex,
-                           removed.items = removableItems)))
+                           removed.items = removableItems,
+                           file = file,
+                           header = table.header,
+                           show = !no.output,
+                           use.viewer = use.viewer))
 }
