@@ -1,24 +1,24 @@
 #' @title Summary of contingency tables as HTML table
 #' @name sjt.xtab
-#' 
+#'
 #' @description Shows contingency tables as HTML file in browser or viewer pane, or saves them as file.
-#' 
+#'
 #' @seealso \itemize{
 #'            \item \href{http://www.strengejacke.de/sjPlot/sjt.xtab}{sjPlot manual: sjt.xtab}
 #'            \item \code{\link{sjp.xtab}}
 #'          }
-#'              
-#' @param var.row variable that should be displayed in the table rows.
-#' @param var.col variable that should be displayed in the table columns.
-#' @param var.labels character vector with variable names, which will be used 
+#'
+#' @param var.row Variable that should be displayed in the table rows.
+#' @param var.col Cariable that should be displayed in the table columns.
+#' @param var.labels Character vector with variable names, which will be used
 #'          to label variables in the output.
-#' @param string.total label for the total column / row header
-#' @param show.cell.prc logical, if \code{TRUE}, cell percentage values are shown
-#' @param show.row.prc logical, if \code{TRUE}, row percentage values are shown
-#' @param show.col.prc logical, if \code{TRUE}, column percentage values are shown
-#' @param show.obs logical, if \code{TRUE}, observed values are shown
-#' @param show.exp logical, if \code{TRUE}, expected values are also shown
-#' @param show.summary logical, if \code{TRUE}, a summary row with 
+#' @param string.total Character label for the total column / row header
+#' @param show.cell.prc Logical, if \code{TRUE}, cell percentage values are shown
+#' @param show.row.prc Logical, if \code{TRUE}, row percentage values are shown
+#' @param show.col.prc Logical, if \code{TRUE}, column percentage values are shown
+#' @param show.obs Logical, if \code{TRUE}, observed values are shown
+#' @param show.exp Logical, if \code{TRUE}, expected values are also shown
+#' @param show.summary Logical, if \code{TRUE}, a summary row with
 #'          chi-squared statistics, degrees of freedom and Cramer's V or Phi
 #'          coefficient and p-value for the chi-squared statistics.
 #' @param tdcol.n Color for highlighting count (observed) values in table cells. Default is black.
@@ -26,9 +26,9 @@
 #' @param tdcol.cell Color for highlighting cell percentage values in table cells. Default is red.
 #' @param tdcol.row Color for highlighting row percentage values in table cells. Default is blue.
 #' @param tdcol.col Color for highlighting column percentage values in table cells. Default is green.
-#' @param emph.total logical, if \code{TRUE}, the total column and row will be emphasized with a
+#' @param emph.total Logical, if \code{TRUE}, the total column and row will be emphasized with a
 #'          different background color. See \code{emph.color}.
-#' @param emph.color logical, if \code{emph.total = TRUE}, this color value will be used
+#' @param emph.color Logical, if \code{emph.total = TRUE}, this color value will be used
 #'          for painting the background of the total column and row. Default is a light grey.
 #' @param prc.sign The percentage sign that is printed in the table cells, in HTML-format.
 #'          Default is \code{"&nbsp;\%"}, hence the percentage sign has a non-breaking-space after
@@ -40,12 +40,12 @@
 #'          \code{"kendall"} or \code{"pearson"}. See 'Details'.
 #' @param ... Other arguments, currently passed down to the test statistics functions
 #'        \code{chisq.test()} or \code{fisher.test()}.
-#'          
+#'
 #' @inheritParams sjt.frq
 #' @inheritParams sjt.df
 #' @inheritParams sjp.glmer
 #' @inheritParams sjp.grpfrq
-#'          
+#'
 #' @return Invisibly returns
 #'          \itemize{
 #'            \item the web page style sheet (\code{page.style}),
@@ -54,7 +54,7 @@
 #'            \item the html-table with inline-css for use with knitr (\code{knitr})
 #'            }
 #'            for further use.
-#'          
+#'
 #' @details The p-value for Cramer's V and the Phi coefficient are based
 #'          on \code{chisq.test()}. If any expected value of a table cell is
 #'          smaller than 5, or smaller than 10 and the df is 1, then \code{fisher.test()}
@@ -67,33 +67,44 @@
 #'          When \code{statistics = "auto"}, only Cramer's V or Phi are calculated,
 #'          based on the dimension of the table (i.e. if the table has more than
 #'          two rows or columns, Cramer's V is calculated, else Phi).
-#'         
-#' @examples 
+#'
+#' @examples
 #' # prepare sample data set
 #' library(sjmisc)
 #' data(efc)
-#' efc.labels <- get_labels(efc)
-#' 
+#'
 #' # print simple cross table with labels
 #' \dontrun{
 #' sjt.xtab(efc$e16sex, efc$e42dep)
-#'          
+#'
 #' # print cross table with manually set
 #' # labels and expected values
-#' sjt.xtab(efc$e16sex, efc$e42dep, var.labels = c("Elder's gender", 
-#'          "Elder's dependency"), value.labels = list(efc.labels[['e16sex']], 
+#' sjt.xtab(efc$e16sex, efc$e42dep, var.labels = c("Elder's gender",
+#'          "Elder's dependency"), value.labels = list(efc.labels[['e16sex']],
 #'          efc.labels[['e42dep']]), show.exp = TRUE)
-#' 
+#'
 #' # print minimal cross table with labels, total col/row highlighted
 #' sjt.xtab(efc$e16sex, efc$e42dep, show.cell.prc = FALSE, emph.total = TRUE)
-#' 
+#'
 #' # User defined style sheet
-#' sjt.xtab(efc$e16sex, efc$e42dep, 
+#' sjt.xtab(efc$e16sex, efc$e42dep,
 #'          CSS = list(css.table = "border: 2px solid;",
 #'                     css.tdata = "border: 1px solid;",
 #'                     css.horline = "border-bottom: double blue;"))}
 #'
-#' @importFrom stats xtabs ftable chisq.test fisher.test
+#' # ordinal data, use Kendall's tau
+#' sjt.xtab(efc$e42dep, efc$quol_5, statistics = "kendall")
+#'
+#' # calculate Spearman's rho, with continuity correction
+#' sjt.xtab(
+#'   efc$e42dep,
+#'   efc$quol_5,
+#'   statistics = "spearman",
+#'   exact = FALSE,
+#'   continuity = TRUE
+#' )
+#'
+#' @importFrom stats ftable
 #' @export
 sjt.xtab <- function(var.row,
                      var.col,
@@ -225,7 +236,7 @@ sjt.xtab <- function(var.row,
   # table init
   # -------------------------------------
   # init web page header
-  toWrite <- sprintf("<html>\n<head>\n<meta http-equiv=\"Content-type\" content=\"text/html;charset=%s\">\n", encoding)
+  toWrite <- table.header <- sprintf("<html>\n<head>\n<meta http-equiv=\"Content-type\" content=\"text/html;charset=%s\">\n", encoding)
   # -------------------------------------
   # init style sheet and tags used for css-definitions
   # we can use these variables for string-replacement
@@ -283,12 +294,12 @@ sjt.xtab <- function(var.row,
   # -------------------------------------
   # set style sheet
   # -------------------------------------
-  page.style <- sprintf("<style>\n%s { %s }\n%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { color:%s }\n.%s { color:%s }\n.%s { color:%s }\n.%s { color:%s }\n.%s { color:%s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n</style>", 
-                        tag.table, css.table, tag.caption, css.caption, tag.thead, css.thead, tag.tdata, css.tdata, tag.secondtablerow, css.secondtablerow, 
-                        tag.leftalign, css.leftalign, tag.centeralign, css.centeralign, tag.lasttablerow, css.lasttablerow, 
+  page.style <- sprintf("<style>\n%s { %s }\n%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { color:%s }\n.%s { color:%s }\n.%s { color:%s }\n.%s { color:%s }\n.%s { color:%s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n</style>",
+                        tag.table, css.table, tag.caption, css.caption, tag.thead, css.thead, tag.tdata, css.tdata, tag.secondtablerow, css.secondtablerow,
+                        tag.leftalign, css.leftalign, tag.centeralign, css.centeralign, tag.lasttablerow, css.lasttablerow,
                         tag.totcol, css.totcol, tag.tothi, css.tothi,
                         tag.td_n, tdcol.n, tag.td_c, tdcol.cell, tag.td_rw, tdcol.row,
-                        tag.td_cl, tdcol.col, tag.td_ex, tdcol.expected, 
+                        tag.td_cl, tdcol.col, tag.td_ex, tdcol.expected,
                         tag.summary, css.summary, tag.horline, css.horline,
                         tag.firstcolborder, css.firstcolborder)
   # start writing content
@@ -357,8 +368,8 @@ sjt.xtab <- function(var.row,
       css_last_row_th <- " "
       css_last_row <- ""
     }
-    page.content <- paste(page.content, 
-                          sprintf("\n    <td class=\"tdata %sleftalign\">%s</td>", 
+    page.content <- paste(page.content,
+                          sprintf("\n    <td class=\"tdata %sleftalign\">%s</td>",
                                   css_last_row_th,
                                   labels.var.row[rowlabelcnt[irow]]))
     # -------------------------------------
@@ -405,7 +416,7 @@ sjt.xtab <- function(var.row,
       # -------------------------------------
       # write table cell data
       # -------------------------------------
-      page.content <- paste(page.content, sprintf("\n    <td class=\"tdata centeralign horline%s\">%s</td>", 
+      page.content <- paste(page.content, sprintf("\n    <td class=\"tdata centeralign horline%s\">%s</td>",
                                                   ifelse(css_last_row == "", css_tot_col, css_last_row),
                                                   cellstring), sep = "")
     }
@@ -416,24 +427,23 @@ sjt.xtab <- function(var.row,
   # table summary
   # -------------------------------------
   if (show.summary) {
-    xt_stat <- xtab_stats(data.frame(var.row, var.col), statistics = statistics, ...)
-    chsq <- stats::chisq.test(var.row, var.col)
-    
+    xt_stat <- xtab_stats(data = data.frame(var.row, var.col), statistics = statistics, ...)
+
     # fisher's exact test?
     if (xt_stat$fisher)
       pstring <- "Fisher's p"
     else
       pstring <- "p"
-    
+
     page.content <- paste(
       page.content,
       sprintf(
         "    <td class=\"summary tdata\" colspan=\"%i\">%s=%.3f &middot; df=%i &middot; %s=%.3f &middot; %s=%.3f</td>",
         totalncol + 1,
-        xt_stat$stat.name,
+        xt_stat$stat.html,
         xt_stat$statistic,
-        chsq$parameter,
-        xt_stat$method,
+        xt_stat$df,
+        xt_stat$method.html,
         xt_stat$estimate,
         pstring,
         xt_stat$p.value,
@@ -442,7 +452,7 @@ sjt.xtab <- function(var.row,
     )
     # close table row
     page.content <- paste(page.content, "\n  </tr>\n")
-  }  
+  }
   # -------------------------------------
   # finish table
   # -------------------------------------
@@ -469,16 +479,16 @@ sjt.xtab <- function(var.row,
     # show row percentage?
     # -----------------
     if (show.row.prc) {
-      page.content <- paste(page.content, 
-                            sprintf("<span class=\"td_rw\">&#37; within %s</span><br>\n", 
+      page.content <- paste(page.content,
+                            sprintf("<span class=\"td_rw\">&#37; within %s</span><br>\n",
                                     gsub("<br>", " ", s.var.row, fixed = TRUE)))
     }
     # -----------------
     # show row percentage?
     # -----------------
     if (show.col.prc) {
-      page.content <- paste(page.content, 
-                            sprintf("<span class=\"td_cl\">&#37; within %s</span><br>\n", 
+      page.content <- paste(page.content,
+                            sprintf("<span class=\"td_cl\">&#37; within %s</span><br>\n",
                                     gsub("<br>", " ", s.var.col, fixed = TRUE)))
     }
     # -----------------
@@ -519,21 +529,21 @@ sjt.xtab <- function(var.row,
   knitr <- gsub(tag.thead, css.thead, knitr, fixed = TRUE, useBytes = TRUE)
   knitr <- gsub(tag.secondtablerow, css.secondtablerow, knitr, fixed = TRUE, useBytes = TRUE)
   knitr <- gsub(tag.firstcolborder, css.firstcolborder, knitr, fixed = TRUE, useBytes = TRUE)
-  knitr <- gsub(tag.leftalign, css.leftalign, knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.centeralign, css.centeralign, knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.horline, css.horline, knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.lasttablerow, css.lasttablerow, knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.totcol, css.totcol, knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.summary, css.summary, knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.tothi, css.tothi, knitr, fixed = TRUE, useBytes = TRUE)  
+  knitr <- gsub(tag.leftalign, css.leftalign, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.centeralign, css.centeralign, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.horline, css.horline, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.lasttablerow, css.lasttablerow, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.totcol, css.totcol, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.summary, css.summary, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.tothi, css.tothi, knitr, fixed = TRUE, useBytes = TRUE)
   # -------------------------------------
   # replace color-attributes for legend
   # -------------------------------------
-  knitr <- gsub(tag.td_ex, sprintf("color:%s;",tdcol.expected), knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.td_cl, sprintf("color:%s;",tdcol.col), knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.td_rw, sprintf("color:%s;",tdcol.row), knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.td_c, sprintf("color:%s;",tdcol.cell), knitr, fixed = TRUE, useBytes = TRUE)  
-  knitr <- gsub(tag.td_n, sprintf("color:%s;",tdcol.n), knitr, fixed = TRUE, useBytes = TRUE)  
+  knitr <- gsub(tag.td_ex, sprintf("color:%s;",tdcol.expected), knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.td_cl, sprintf("color:%s;",tdcol.col), knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.td_rw, sprintf("color:%s;",tdcol.row), knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.td_c, sprintf("color:%s;",tdcol.cell), knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.td_n, sprintf("color:%s;",tdcol.n), knitr, fixed = TRUE, useBytes = TRUE)
   # -------------------------------------
   # remove spaces?
   # -------------------------------------
@@ -543,70 +553,105 @@ sjt.xtab <- function(var.row,
     page.content <- sju.rmspc(page.content)
   }
   # -------------------------------------
-  # check if html-content should be printed
-  # -------------------------------------
-  out.html.table(no.output, file, knitr, toWrite, use.viewer)   
-  # -------------------------------------
   # return results
   # -------------------------------------
-  invisible(structure(class = c("sjTable", "sjtxtab"),
+  structure(class = c("sjTable", "sjtxtab"),
                       list(page.style = page.style,
                            page.content = page.content,
                            output.complete = toWrite,
-                           knitr = knitr)))
+                           knitr = knitr,
+                           header = table.header,
+                           file = file,
+                           show = !no.output,
+                           use.viewer = use.viewer))
 }
 
 
-#' @importFrom stats fisher.test chisq.test cor.test ftable
 #' @importFrom dplyr case_when
 #' @importFrom sjstats table_values cramer phi
-xtab_stats <- function(data, statistics = c("auto", "cramer", "phi", "spearman", "kendall", "pearson"), ...) {
+#' @importFrom stats fisher.test cor.test chisq.test
+xtab_stats <- function(data, x1 = NULL, x2 = NULL, statistics = c("auto", "cramer", "phi", "spearman", "kendall", "pearson"), ...) {
   # match arguments
   statistics <- match.arg(statistics)
 
-  # copy data as table  
-  tab <- table(data)
+  # name for test statistics in HTML
+  stat.html <- NULL
+
+  # check if data is a table
+  if (!is.table(data)) {
+    # evaluate unquoted names
+    x1 <- deparse(substitute(x1))
+    x2 <- deparse(substitute(x2))
+
+    # if names were quotes, remove quotes
+    x1 <- gsub("\"", "", x1, fixed = T)
+    x2 <- gsub("\"", "", x2, fixed = T)
+
+    # check for "NULL" and get data
+    if (x1 != "NULL" && x2 != "NULL")
+      data <- data[, c(x1, x2)]
+    else
+      data <- data[, 1:2]
+
+    # make simple table
+    tab <- table(data)
+  } else {
+    # 'data' is a table - copy to table object
+    tab <- data
+    # check if statistics are possible to compute
+    if (statistics %in% c("spearman", "kendall", "pearson")) {
+      stop(
+        sprintf(
+          "Need arguments `data`, `x1` and `x2` to compute %s-statistics.",
+          statistics
+        ),
+        call. = F
+      )
+    }
+  }
 
   # get expected values
   tab.val <- sjstats::table_values(tab)
-  
+
   # remember whether fisher's exact test was used or not
   use.fisher <- FALSE
-  
+
   # select statistics automatically, based on number of rows/columns
   if (statistics %in% c("auto", "cramer", "phi")) {
     # get chisq-statistics, for df and p-value
     chsq <- suppressWarnings(stats::chisq.test(tab, ...))
     pv <- chsq$p.value
     test <- chsq$statistic
+
     # set statistics name
     names(test) <- "Chi-squared"
-    
+    stat.html <- "&chi;<sup>2</sup>"
+
     # check row/column
     if ((nrow(tab) > 2 || ncol(tab) > 2 || statistics == "cramer") && statistics != "phi") {
       # get cramer's V
       s <- sjstats::cramer(tab)
-      
+
       # if minimum expected values below 5, compute fisher's exact test
       if (min(tab.val$expected) < 5 ||
           (min(tab.val$expected) < 10 && chsq$parameter == 1)) {
         pv <- stats::fisher.test(tab, simulate.p.value = TRUE, ...)$p.value
         use.fisher <- TRUE
       }
-      
+
       # set statistics
       statistics <- "cramer"
     } else {
       # get Phi
       s <- sjstats::phi(tab)
-      
+
       # if minimum expected values below 5 and df=1, compute fisher's exact test
       if (min(tab.val$expected) < 5 ||
           (min(tab.val$expected) < 10 && chsq$parameter == 1)) {
         pv <- stats::fisher.test(tab, ...)$p.value
         use.fisher <- TRUE
       }
-      
+
       # set statistics
       statistics <- "phi"
     }
@@ -617,8 +662,9 @@ xtab_stats <- function(data, statistics = c("auto", "cramer", "phi", "spearman",
     s <- cv$estimate
     pv <- cv$p.value
     test <- cv$statistic
+    stat.html <- names(test)
   }
-  
+
   # compute method string
   method <- dplyr::case_when(
     statistics == "kendall" ~ "Kendall's tau",
@@ -627,15 +673,27 @@ xtab_stats <- function(data, statistics = c("auto", "cramer", "phi", "spearman",
     statistics == "cramer" ~ "Cramer's V",
     statistics == "phi" ~ "Phi"
   )
-  
+
+  # compute method string
+  method.html <- dplyr::case_when(
+    statistics == "kendall" ~ "Kendall's &tau;",
+    statistics == "spearman" ~ "Spearman's &rho;",
+    statistics == "pearson" ~ "Person's r",
+    statistics == "cramer" ~ "Cramer's V",
+    statistics == "phi" ~ "&phi;"
+  )
+
   # return result
-  return(list(
+  return(structure(class = "sj_xtab_stat", list(
     estimate = s,
     p.value = pv,
     statistic = test,
     stat.name = names(test),
+    stat.html = stat.html,
+    df = (nrow(tab) - 1) * (ncol(tab) - 1),
     method = method,
+    method.html = method.html,
     method.short = statistics,
     fisher = use.fisher
-  ))
+  )))
 }
