@@ -3,31 +3,30 @@
 #'
 #' @description Save (or show) content of an imported SPSS, SAS or Stata data file,
 #'                or any similar labelled \code{data.frame}, as HTML table.
-#'                Similar to the SPSS variable view. This quick overview shows
-#'                variable ID numner, name, label, type and associated
-#'                value labels. The result can be considered as "codeplan" of
-#'                the data frame.
+#'                This quick overview shows variable ID number, name, label,
+#'                type and associated value labels. The result can be
+#'                considered as "codeplan" of the data frame.
 #'
 #' @seealso \itemize{
 #'            \item \href{http://www.strengejacke.de/sjPlot/datainit/}{sjPlot manual: data initialization}
 #'            \item \href{http://www.strengejacke.de/sjPlot/view_spss/}{sjPlot manual: inspecting (SPSS imported) data frames}
 #'          }
 #'
-#' @param x \code{data.frame}, imported by \code{\link[sjmisc]{read_spss}},
+#' @param x A (labelled) data frame, imported by \code{\link[sjmisc]{read_spss}},
 #'          \code{\link[sjmisc]{read_sas}} or \code{\link[sjmisc]{read_stata}} function,
 #'          or any similar labelled data frame (see \code{\link[sjmisc]{set_label}}
 #'          and \code{\link[sjmisc]{set_labels}}).
-#' @param show.id logical, if \code{TRUE} (default), the variable ID is shown in the first column.
-#' @param show.values logical, if \code{TRUE} (default), the variable values are shown as additional column.
-#' @param show.labels logical, if \code{TRUE} (default), the value labels are shown as additional column.
-#' @param show.frq logical, if \code{TRUE}, an additional column with frequencies for each variable is shown.
-#' @param show.prc logical, if \code{TRUE}, an additional column with percentage of frequencies for each variable is shown.
-#' @param show.wtd.frq logical, if \code{TRUE}, an additional column with weighted
+#' @param show.id Logical, if \code{TRUE} (default), the variable ID is shown in the first column.
+#' @param show.values Logical, if \code{TRUE} (default), the variable values are shown as additional column.
+#' @param show.labels Logical, if \code{TRUE} (default), the value labels are shown as additional column.
+#' @param show.frq Logical, if \code{TRUE}, an additional column with frequencies for each variable is shown.
+#' @param show.prc Logical, if \code{TRUE}, an additional column with percentage of frequencies for each variable is shown.
+#' @param show.wtd.frq Logical, if \code{TRUE}, an additional column with weighted
 #'          frequencies for each variable is shown. Weights strem from \code{weight.by}.
-#' @param show.wtd.prc logical, if \code{TRUE}, an additional column with weighted
+#' @param show.wtd.prc Logical, if \code{TRUE}, an additional column with weighted
 #'          percentage of frequencies for each variable is shown.
 #'          Weights strem from \code{weight.by}.
-#' @param sort.by.name logical, if \code{TRUE}, rows are sorted according to the variable
+#' @param sort.by.name Logical, if \code{TRUE}, rows are sorted according to the variable
 #'          names. By default, rows (variables) are ordered according to their
 #'          order in the data frame.
 #'
@@ -64,9 +63,7 @@
 #' # view variables including variable typed, orderd by name
 #' view_df(efc, sort.by.name = TRUE, show.type = TRUE)
 #'
-#' # ----------------------------------------------------------------
 #' # User defined style sheet
-#' # ----------------------------------------------------------------
 #' view_df(efc,
 #'         CSS = list(css.table = "border: 2px solid;",
 #'                    css.tdata = "border: 1px solid;",
@@ -98,19 +95,19 @@ view_df <- function(x,
                     remove.spaces = TRUE) {
   # check encoding
   encoding <- get.encoding(encoding, x)
-  
+
   # make data frame of single variable, so we have
   # unique handling for the data
   if (!is.data.frame(x)) stop("Parameter needs to be a data frame!", call. = FALSE)
-  
+
   # retrieve value and variable labels
   df.var <- sjmisc::get_label(x)
   df.val <- sjmisc::get_labels(x)
-  
+
   # get row count and ID's
   colcnt <- ncol(x)
   id <- seq_len(colcnt)
-  
+
   # Order data set if requested
   if (sort.by.name) id <- id[order(colnames(x))]
 
@@ -127,7 +124,7 @@ view_df <- function(x,
   css.tdata <- "padding:0.2cm; text-align:left; vertical-align:top;"
   css.arc <- "background-color:#eaeaea"
   css.caption <- "font-weight: bold; text-align:left;"
-  
+
   # check user defined style sheets
   if (!is.null(CSS)) {
     if (!is.null(CSS[['css.table']])) css.table <- ifelse(substring(CSS[['css.table']], 1, 1) == '+', paste0(css.table, substring(CSS[['css.table']], 2)), CSS[['css.table']])
@@ -136,18 +133,18 @@ view_df <- function(x,
     if (!is.null(CSS[['css.arc']])) css.arc <- ifelse(substring(CSS[['css.arc']], 1, 1) == '+', paste0(css.arc, substring(CSS[['css.arc']], 2)), CSS[['css.arc']])
     if (!is.null(CSS[['css.caption']])) css.caption <- ifelse(substring(CSS[['css.caption']], 1, 1) == '+', paste0(css.caption, substring(CSS[['css.caption']], 2)), CSS[['css.caption']])
   }
-  
+
   # set style sheet
   page.style <- sprintf("<style>\n%s { %s }\n.%s { %s }\n.%s { %s }\n.%s { %s }\n%s { %s }\n</style>",
                         tag.table, css.table, tag.thead, css.thead, tag.tdata, css.tdata,
                         tag.arc, css.arc, tag.caption, css.caption)
-  
+
   # table init
   toWrite <- sprintf("<html>\n<head>\n<meta http-equiv=\"Content-type\" content=\"text/html;charset=%s\">\n%s\n</head>\n<body>\n", encoding, page.style)
-  
+
   # table caption, data frame name
   page.content <- sprintf("<table>\n  <caption>Data frame: %s</caption>\n", deparse(substitute(x)))
-  
+
   # header row
   page.content <- paste0(page.content, "  <tr>\n    ")
   if (show.id) page.content <- paste0(page.content, "<th class=\"thead\">ID</th>")
@@ -162,33 +159,33 @@ view_df <- function(x,
   if (show.wtd.frq) page.content <- paste0(page.content, "<th class=\"thead\">weighted Freq.</th>")
   if (show.wtd.prc) page.content <- paste0(page.content, "<th class=\"thead\">weighted %</th>")
   page.content <- paste0(page.content, "\n  </tr>\n")
-  
+
   # create progress bar
   if (!hide.progress) pb <- utils::txtProgressBar(min = 0, max = colcnt, style = 3)
-  
+
   # subsequent rows
   for (ccnt in seq_len(colcnt)) {
     # get index number, depending on sorting
     index <- id[ccnt]
     # default row string
     arcstring <- ""
-    
+
     # if we have alternating row colors, set css
     if (altr.row.col) arcstring <- ifelse(sjmisc::is_even(ccnt), " arc", "")
     page.content <- paste0(page.content, "  <tr>\n")
-    
+
     # ID
     if (show.id)
       page.content <-
       paste0(page.content,
              sprintf("    <td class=\"tdata%s\">%i</td>\n", arcstring, index))
-    
+
     # name, and note
     if (!is.null(sjmisc::get_note(x[[index]])))
       td.title.tag <- sprintf(" title=\"%s\"", sjmisc::get_note(x[[index]]))
     else
       td.title.tag <- ""
-    
+
     page.content <-
       paste0(
         page.content,
@@ -199,7 +196,7 @@ view_df <- function(x,
           colnames(x)[index]
         )
       )
-    
+
     # type
     if (show.type) {
       vartype <- get.vartype(x[[index]])
@@ -218,7 +215,7 @@ view_df <- function(x,
       varlab <- "<NA>"
     }
     page.content <- paste0(page.content, sprintf("    <td class=\"tdata%s\">%s</td>\n", arcstring, varlab))
-    
+
     # missings and missing percentage
     if (show.na) {
       page.content <- paste0(
@@ -254,7 +251,7 @@ view_df <- function(x,
         paste0(page.content,
                sprintf("    <td class=\"tdata%s\">%s</td>\n", arcstring, valstring))
     }
-    
+
     # value labels
     if (show.labels) {
       valstring <- ""
@@ -277,7 +274,7 @@ view_df <- function(x,
       }
       page.content <- paste0(page.content, sprintf("    <td class=\"tdata%s\">%s</td>\n", arcstring, valstring))
     }
-    
+
     # frequencies
     if (show.frq) {
       page.content <-
@@ -288,7 +285,7 @@ view_df <- function(x,
                  frq.value(index, x, df.val)
                ))
     }
-    
+
     # percentage of frequencies
     if (show.prc) {
       page.content <-
@@ -299,7 +296,7 @@ view_df <- function(x,
                  prc.value(index, x, df.val)
                ))
     }
-    
+
     # frequencies
     if (show.wtd.frq && !is.null(weight.by)) {
       page.content <-
@@ -310,7 +307,7 @@ view_df <- function(x,
                  frq.value(index, x, df.val, weight.by)
                ))
     }
-    
+
     # percentage of frequencies
     if (show.prc && !is.null(weight.by)) {
       page.content <-
@@ -321,51 +318,55 @@ view_df <- function(x,
                  prc.value(index, x, df.val, weight.by)
                ))
     }
-    
+
     # update progress bar
     if (!hide.progress) utils::setTxtProgressBar(pb, ccnt)
     # close row tag
     page.content <- paste0(page.content, "  </tr>\n")
   }
   if (!hide.progress) close(pb)
-  
+
   # finish html page
   page.content <- paste(page.content, "</table>", sep = "\n")
   toWrite <- paste0(toWrite, sprintf("%s\n</body></html>", page.content))
-  
+
   # replace class attributes with inline style,
   # useful for knitr
   knitr <- page.content
-  
+
   # set style attributes for main table tags
   knitr <- gsub("class=", "style=", knitr, fixed = TRUE, useBytes = TRUE)
   knitr <- gsub("<table", sprintf("<table style=\"%s\"", css.table), knitr, fixed = TRUE, useBytes = TRUE)
-  
+
   # replace class-attributes with inline-style-definitions
   knitr <- gsub(tag.tdata, css.tdata, knitr, fixed = TRUE, useBytes = TRUE)
   knitr <- gsub(tag.thead, css.thead, knitr, fixed = TRUE, useBytes = TRUE)
   knitr <- gsub(tag.arc, css.arc, knitr, fixed = TRUE, useBytes = TRUE)
-  
+
   # remove spaces?
   if (remove.spaces) {
     knitr <- sju.rmspc(knitr)
     toWrite <- sju.rmspc(toWrite)
     page.content <- sju.rmspc(page.content)
   }
-  
+
   # check if html-content should be outputted
-  out.html.table(no.output, file, knitr, toWrite, use.viewer)
-  
+  #out.html.table(no.output, file, knitr, toWrite, use.viewer)
+
   # return results
-  invisible(structure(
+  structure(
     class = c("sjTable", "view_df"),
     list(
       page.style = page.style,
       page.content = page.content,
       output.complete = toWrite,
-      knitr = knitr
+      header = NULL,
+      knitr = knitr,
+      file = file,
+      show = !no.output,
+      use.viewer = use.viewer
     )
-  ))
+  )
 }
 
 
@@ -420,4 +421,4 @@ prc.value <- function(index, x, df.val, weights = NULL) {
     valstring <- ""
   }
   return(valstring)
-}
\ No newline at end of file
+}
