@@ -296,7 +296,7 @@ sjt.stackfrq <- function(items,
   # -------------------------------------
   # init header
   # -------------------------------------
-  toWrite <- sprintf("<html>\n<head>\n<meta http-equiv=\"Content-type\" content=\"text/html;charset=%s\">\n", encoding)
+  toWrite <- table.header <- sprintf("<html>\n<head>\n<meta http-equiv=\"Content-type\" content=\"text/html;charset=%s\">\n", encoding)
   # -------------------------------------
   # init style sheet and tags used for css-definitions
   # we can use these variables for string-replacement
@@ -457,15 +457,15 @@ sjt.stackfrq <- function(items,
     page.content <- sju.rmspc(page.content)
   }
   # -------------------------------------
-  # check if html-content should be outputted
-  # -------------------------------------
-  out.html.table(no.output, file, knitr, toWrite, use.viewer) 
-  # -------------------------------------
   # return results
   # -------------------------------------
-  invisible(structure(class = "sjtstackfrq",
+  structure(class = c("sjTable", "sjtstackfrq"),
                       list(page.style = page.style,
                            page.content = page.content,
                            output.complete = toWrite,
-                           knitr = knitr)))
+                           header = table.header,
+                           knitr = knitr,
+                           file = file,
+                           show = !no.output,
+                           use.viewer = use.viewer))
 }
